@@ -20,7 +20,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: ActionManager.java 4156 2009-06-24 16:51:26Z alitokmen $
+ * $Id: ActionManager.java 4310 2009-07-07 14:41:06Z chahinem $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jasmine.jadort.service.implementation;
@@ -372,25 +372,27 @@ public class ActionManager extends OperationPersistenceManager {
     protected void fillApplications(final GroupBean groupBean) throws JadortServiceException {
         SortedMap<String, ApplicationBean> groupApplications = new TreeMap<String, ApplicationBean>();
 
-        for (ServerBean serverBean : groupBean.getServers()) {
-            ServerAction serverAction = ServerAction.getServerAction(serverBean);
-            try {
-                SortedMap<String, ApplicationBean> serverApplications = new TreeMap<String, ApplicationBean>();
+        if (groupBean.getConnected()) {
+            for (ServerBean serverBean : groupBean.getServers()) {
+                ServerAction serverAction = ServerAction.getServerAction(serverBean);
+                try {
+                    SortedMap<String, ApplicationBean> serverApplications = new TreeMap<String, ApplicationBean>();
 
-                for (ApplicationBean applicationBean : serverAction.listOfApplications()) {
-                    groupApplications.put(applicationBean.toString(), applicationBean);
-                    serverApplications.put(applicationBean.toString(), applicationBean);
+                    for (ApplicationBean applicationBean : serverAction.listOfApplications()) {
+                        groupApplications.put(applicationBean.toString(), applicationBean);
+                        serverApplications.put(applicationBean.toString(), applicationBean);
+                    }
+
+                    serverBean.setApplications(new ArrayList<ApplicationBean>(serverApplications.values()));
+                } catch (Exception e) {
+                    String message = e.getClass().getName() + ": " + e.getMessage();
+                    throw new JadortServiceException("Failed getting the applications on the server " + serverBean.getName()
+                        + ": " + message, e);
                 }
-
-                serverBean.setApplications(new ArrayList<ApplicationBean>(serverApplications.values()));
-            } catch (Exception e) {
-                String message = e.getClass().getName() + ": " + e.getMessage();
-                throw new JadortServiceException("Failed getting the applications on the server " + serverBean.getName() + ": "
-                    + message, e);
             }
-        }
 
-        groupBean.setApplications(new ArrayList<ApplicationBean>(groupApplications.values()));
+            groupBean.setApplications(new ArrayList<ApplicationBean>(groupApplications.values()));
+        }
     }
 
     /**
@@ -441,6 +443,7 @@ public class ActionManager extends OperationPersistenceManager {
                 groupBeanCopy.setName(groupBean.getName());
                 groupBeanCopy.setServers(new ArrayList<ServerBean>(groupBean.getServers()));
                 groupBeanCopy.setClustered(groupBean.getClustered());
+                groupBeanCopy.setConnected(groupBean.getConnected());
                 if (fillApplications) {
                     this.fillApplications(groupBeanCopy);
                 }
